function [VN,VR,VCh]=all_twoconcentrations(A,L,pozadi,gr,w)

%[VN,VR,VCh]=all_twoconcentrations(A,L,pozadi,gr,w)

%Runs in a cycle the function "two_concentrations.m" and eventually shows related graphs.

%"A" is a matrix, where the first column are wavelengths, 

%  the second and third columns are absorption coefficients of both species 

%  and the other columns are measured absorbances of mixtures of both species. 

%"L" is the cuvette length (the length that light travels through the solution)

%The parameter "pozadi" determines whether the background will be fitted (for pozadi=1] 

% or not (for pozadi=0). 

%"gr" determines, whether the fit will be plotted (for gr=1) or not (for gr=0). 

%"w" is the vector of weights. If weights should not be taken into account 

% (i.e. all points should have equal weigths), w=[] can be used. 

%

%"VN" is a matrix with fitted concentrations 

% (result of each measurement is shown in an individual line). 

% If pozadi=1, a third column is added to the matrix "VN" with the background level. 

%"VR" is the matrix of standard errors of data in the matrix "VN". 

%"VCh" is the matrix with an approximate information, how high relative part of sum of squares 

% is related to the spectrum of the first and to the spectrum of the second species. 



[m,n]=size(A);

for j=1:n-3, 

 M=A(:,[2 3 j+3]); %Makes the matrix for one of experiments that will be actually treated by the function "two_concentrations.m".  

 if length(w)==m

  M=[M w]; %Pridani vah 

 elseif length(w)==0

  %Vahy se nedodavaji

 else 0

  error('Spatna delka vektoru vah'); 

 end

 [N,R,Ch]=two_concentrations(M,L,pozadi); %Fit

 if gr==1

  y=N(1)*M(:,1) + N(2)*M(:,2);

  y=y*L; 

  if pozadi==1

   y=y+N(3);

  end

   %"y" je fit absorbance 

  figure; plot(A(:,1),A(:,j+3),'-b.',A(:,1),y,'r',A(:,1),y-A(:,j+3),'k'); grid on; 

  hold on; plot(A(:,1),A(:,2)*N(1)*L,'c--',A(:,1),A(:,3)*N(2)*L,'g--'); %The fitted spectra of both species 

  if pozadi==1

   plot(A(:,1),N(3)*ones(size(A(:,1))),'m-.'); %Plot of the background level  

  end

  legend('Measurement','Fit','Error'); xlabel('Wavelength'); ylabel('Absorbance'); 

 end

 VN(j,:)=N.'; %Matrix of all concentrations (and, eventually, backgound values) 

 VR(j,:)=R.'; %Matrix of standard errors

 VCh(j,:)=Ch(2,:); %Matrix with iformation related to the division of sum of squares between both spectra  

end

[a,b]=size(VN);

soucet= [VN(:,1)+VN(:,2)];prm=mean(soucet)

st=std(soucet)*sqrt((a-1)/a)

s=[VR(:,1)+VR(:,2)];

se=(sum(s))

%conc1 = mean(VN(1:3,1)+VN(1:3,2))

%conc2 = mean(VN(4:6,1)+VN(4:6,2))

%conc3 = mean(VN(end-2:end,1)+VN(end-2:end,2))

figure; plot((1:a),VN(:,1),'rx',(1:a),VN(:,2),'gx');title('Concentrations') 

figure; plot((1:a), [VN(:,1)+VN(:,2)],'rx');title('Sum')

figure; plot((1:a), VR(:,1),'rx',(1:a),VR(:,2),'gx');title('VR')

figure; plot((1:a), VCh(:,1),'rx',(1:a),VCh(:,2),'gx'); title('VCh')

